<template>
  <el-dialog
    :title="title"
    :visible.sync="open"
    append-to-body
    width="50%"
    :before-close="handleClose"
  >
    <el-form ref="ruleForm" :model="form"  :rules="rules" label-position="right" label-width="150px" style="padding-right: 50px" element-loading-text="保存中...">
      <el-form-item label="姓名:" prop="name">
        <el-input v-model.trim="form.name" />
      </el-form-item>
      <el-form-item label="身份证:" prop="idCard">
        <el-input v-model.trim="form.idCard" type="number" />
      </el-form-item>
      <el-form-item label="科目:" prop="subjectId">
        <el-cascader
          ref="cascaderRef"
          v-model="form.subjectId"
          :options="dataList"
          style="width: 100%"
          :props="{ expandTrigger: 'hover', value: 'id',label: 'name',emitPath: false, checkStrictly: true }"
          @change="getArriveListName"
          ></el-cascader>
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button type="primary" @click="queryGrade">确认查询</el-button>
      <el-button @click="handleClose">取消</el-button>
    </span>
    <query-grade-dialog ref="queryGradeDialog"></query-grade-dialog>
  </el-dialog>
</template>

<script >
import {addExamApply, editExamApply, getExamSite} from "@/api/commonMod/examApply";
import {getTrainPage} from "@/api/coalMine/placeManage/train";
import queryGradeDialog from '@/views/commonMod/examApply/components/queryGradeDialog.vue'
import store from "@/store";
import { getOperatePage } from '@/api/coalMine/operateType'

export default {
  name: 'examApplyDialog',
  components: {
    queryGradeDialog
  },
  props: ['typeList'],
  data() {
    return {
      disable: false,
      title: '成绩查询',
      open: false,
      form:{},
      rules:{
        name: [{ required: true, message: '请填写姓名', trigger: 'blur' }],
        idCard:[{ required: true, message: '请填写身份证号', trigger: 'blur' }],
        subjectId: [{ required: true, message: '请选择科目', trigger: 'change' }],
      },
      isAdmin: false,
      dataList: []
    }
  },
  created() {

  },
  methods: {
    openDialog() {
      const t = this
      const roles = store.getters && store.getters.roles
      if (roles.includes('admin')) {
        t.isAdmin = true
      } else {
        t.isAdmin = false
      }
      if (roles.includes('company')) {
        t.form.isCm = 0
      }
      if (roles.includes('mk')) {
        t.form.isCm = 1
      }
        const userInfo = store.getters && store.getters.userInfo
        t.open = true
        t.reset()
        t.getSubjects()
    },
    isValidKey(key, obj) {
      return key in obj
    },

    handleClose() {
      this.open = false;
      this.reset();
    },


    async getSubjects() {
      const res = await getOperatePage({name: ''})
      if(res.code == 200){
        this.dataList = this.handleTree(res.data, "id");
        console.log(this.dataList,'data')
      }else{
        this.$message({
          type: 'warning',
          message: res.msg
        });
      }
    },
    getArriveListName () {
      this.form.subjectName = this.$refs.cascaderRef.getCheckedNodes()[0].pathLabels.join('/')
    },
    queryGrade() {
      this.$refs["ruleForm"].validate(async(valid) =>{
        if(valid) {
          this.form.grade = '92'
          this.$refs.queryGradeDialog.openDialog(this.form);
        }else{
          this.$message({
            type:'warning',
            message:'请完善必填信息'
          })
        }
      })
    },
    // 表单重置
    reset() {
      this.form = {
        name: '',
        idCard: '',
        subjectId: null,
        subjectName: ''
      }
    },

  }
}

</script>
<style scoped>

</style>
